@@ -74,14 +74,14 @@
 #'   as argument for the \code{data} parameter of the test or model fit
 #'   function.
 #'
-#' @section Computed variables: The output of \code{glance()} is
-#'   returned almost as is in the \code{data} object.
-#'   The names of the columns in the returned data are consitent with those
-#'   returned by method \code{glance()} from package 'broom', that will
-#'   frequently differ from the name of values returned by the print methods
-#'   corresponding to the fit or test function used. To explore the values
-#'   returned by this statistic, which vary depending on the model fitting
-#'   function and model formula we suggest the use of
+#' @return The output of the \code{glance()} methods is returned almost as is in
+#'   the \code{data} object, as a data frame. The names of the columns in the
+#'   returned data are consistent with those returned by method \code{glance()}
+#'   from package 'broom', that will frequently differ from the name of values
+#'   returned by the print methods corresponding to the fit or test function
+#'   used. To explore the values returned by this statistic including the name
+#'   of variables/columns, which vary depending on the model fitting function
+#'   and model formula we suggest the use of
 #'   \code{\link[gginnards]{geom_debug}}. An example is shown below.
 #'
 #' @note Although arguments passed to parameter \code{glance.args} will be
@@ -90,7 +90,7 @@
 #'   documentation for the version of [glance()] corresponding to the `method`
 #'   used to fit the model.
 #'
-#' @family Statistics calling generic tidier methods.
+#' @family ggplot statistics for model fits
 #'
 #' @seealso \code{\link[broom]{broom}} and \code{broom.mixed} for details on how
 #'   the tidying of the result of model fits is done.
@@ -99,16 +99,19 @@
 #'
 #' @examples
 #' library(broom)
-#' library(gginnards)
 #' library(quantreg)
 #'
-#' # Regression by panel example, using geom_debug.
-#' ggplot(mtcars, aes(x = disp, y = mpg)) +
-#'   stat_smooth(method = "lm") +
-#'   geom_point(aes(colour = factor(cyl))) +
-#'   stat_fit_glance(method = "lm",
-#'                   method.args = list(formula = y ~ x),
-#'                   geom = "debug")
+#' # Inspecting the returned data using geom_debug()
+#' if (requireNamespace("gginnards", quietly = TRUE)) {
+#'   library(gginnards)
+#'
+#'   ggplot(mtcars, aes(x = disp, y = mpg)) +
+#'     stat_smooth(method = "lm") +
+#'     geom_point(aes(colour = factor(cyl))) +
+#'     stat_fit_glance(method = "lm",
+#'                     method.args = list(formula = y ~ x),
+#'                     geom = "debug")
+#' }
 #'
 #' # Regression by panel example
 #' ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -118,7 +121,7 @@
 #'                   label.y = "bottom",
 #'                   method.args = list(formula = y ~ x),
 #'                   mapping = aes(label = sprintf('r^2~"="~%.3f~~italic(P)~"="~%.2g',
-#'                                 stat(r.squared), stat(p.value))),
+#'                                 after_stat(r.squared), after_stat(p.value))),
 #'                   parse = TRUE)
 #'
 #' # Regression by group example
@@ -129,7 +132,7 @@
 #'                   label.y = "bottom",
 #'                   method.args = list(formula = y ~ x),
 #'                   mapping = aes(label = sprintf('r^2~"="~%.3f~~italic(P)~"="~%.2g',
-#'                                 stat(r.squared), stat(p.value))),
+#'                                 after_stat(r.squared), after_stat(p.value))),
 #'                   parse = TRUE)
 #'
 #' # Weighted regression example
@@ -140,7 +143,7 @@
 #'                   label.y = "bottom",
 #'                   method.args = list(formula = y ~ x, weights = quote(weight)),
 #'                   mapping = aes(label = sprintf('r^2~"="~%.3f~~italic(P)~"="~%.2g',
-#'                                 stat(r.squared), stat(p.value))),
+#'                                 after_stat(r.squared), after_stat(p.value))),
 #'                   parse = TRUE)
 #'
 #' # correlation test
@@ -150,7 +153,7 @@
 #'                   label.y = "bottom",
 #'                   method.args = list(formula = ~ x + y),
 #'                   mapping = aes(label = sprintf('r[Pearson]~"="~%.3f~~italic(P)~"="~%.2g',
-#'                                 stat(estimate), stat(p.value))),
+#'                                 after_stat(estimate), after_stat(p.value))),
 #'                   parse = TRUE)
 #'
 #' ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -159,7 +162,7 @@
 #'                   label.y = "bottom",
 #'                   method.args = list(formula = ~ x + y, method = "spearman", exact = FALSE),
 #'                   mapping = aes(label = sprintf('r[Spearman]~"="~%.3f~~italic(P)~"="~%.2g',
-#'                                 stat(estimate), stat(p.value))),
+#'                                 after_stat(estimate), after_stat(p.value))),
 #'                   parse = TRUE)
 #'
 #' # Quantile regression by group example
@@ -170,7 +173,7 @@
 #'                   label.y = "bottom",
 #'                   method.args = list(formula = y ~ x),
 #'                   mapping = aes(label = sprintf('AIC = %.3g, BIC = %.3g',
-#'                                 stat(AIC), stat(BIC))))
+#'                                 after_stat(AIC), after_stat(BIC))))
 #'
 stat_fit_glance <- function(mapping = NULL, data = NULL, geom = "text_npc",
                             method = "lm",
@@ -352,8 +355,8 @@ StatFitGlance <-
   ggplot2::ggproto("StatFitGlance", ggplot2::Stat,
                    compute_group = fit_glance_compute_group_fun,
                    default_aes =
-                     ggplot2::aes(npcx = stat(npcx),
-                                  npcy = stat(npcy),
+                     ggplot2::aes(npcx = after_stat(npcx),
+                                  npcy = after_stat(npcy),
                                   hjust = "inward",
                                   vjust = "inward"),
                    required_aes = c("x", "y")
@@ -443,7 +446,7 @@ StatFitGlance <-
 #'   documentation for the version of [augment()] corresponding to the `method`
 #'   used to fit the model.
 #'
-#' @family Statistics calling generic tidier methods.
+#' @family ggplot statistics for model fits
 #'
 #' @seealso \code{\link[broom]{broom}} and \code{broom.mixed} for details on how
 #'   the tidying of the result of model fits is done.
@@ -452,16 +455,20 @@ StatFitGlance <-
 #'
 #' @examples
 #' library(broom)
-#' library(gginnards)
 #' library(quantreg)
 #'
-#' # Regression by panel, using geom_debug() to explore computed variables
-#' ggplot(mtcars, aes(x = disp, y = mpg)) +
-#'   geom_point(aes(colour = factor(cyl))) +
-#'   stat_fit_augment(method = "lm",
-#'                    method.args = list(formula = y ~ x),
-#'                    geom = "debug",
-#'                    summary.fun = colnames)
+#' # Inspecting the returned data using geom_debug()
+#' if (requireNamespace("gginnards", quietly = TRUE)) {
+#'   library(gginnards)
+#'
+#' # Regression by panel
+#'   ggplot(mtcars, aes(x = disp, y = mpg)) +
+#'     geom_point(aes(colour = factor(cyl))) +
+#'     stat_fit_augment(method = "lm",
+#'                      method.args = list(formula = y ~ x),
+#'                      geom = "debug",
+#'                      summary.fun = colnames)
+#' }
 #'
 #' # Regression by panel example
 #' ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -608,8 +615,8 @@ StatFitAugment <-
                    ggplot2::Stat,
                    compute_group = fit_augment_compute_group_fun,
                    default_aes =
-                     ggplot2::aes(ymax = stat(y + .se.fit * t.value),
-                                  ymin = stat(y - .se.fit * t.value)),
+                     ggplot2::aes(ymax = after_stat(y + .se.fit * t.value),
+                                  ymin = after_stat(y - .se.fit * t.value)),
                    required_aes = c("x", "y")
 )
 
@@ -619,7 +626,7 @@ StatFitAugment <-
 #'
 #' @description \code{stat_fit_tidy} fits a model and returns a "tidy" version
 #'   of the model's summary, using '\code{tidy()} methods from packages 'broom',
-#'   'broom.mixed', or other sources.#' To add the summary in tabular form use
+#'   'broom.mixed', or other sources. To add the summary in tabular form use
 #'   \code{\link{stat_fit_tb}} instead of this statistic. When using
 #'   \code{stat_fit_tidy()} you will most likely want to change the default
 #'   mapping for label.
@@ -653,11 +660,13 @@ StatFitAugment <-
 #'   recycled.
 #' @param hstep,vstep numeric in npc units, the horizontal and vertical step
 #'   used between labels for different groups.
+#' @param sanitize.names logical If true sanitize column names in the returned
+#'   \code{data} with R's \code{make.names()} function.
 #'
 #' @details \code{stat_fit_tidy} together with \code{\link{stat_fit_glance}}
 #'   and \code{\link{stat_fit_augment}}, based on package 'broom' can be used
 #'   with a broad range of model fitting functions as supported at any given
-#'   time by 'broom'. In contrast to \code{\link{stat_poly_eq}} wich can
+#'   time by 'broom'. In contrast to \code{\link{stat_poly_eq}} which can
 #'   generate text or expression labels automatically, for these functions the
 #'   mapping of aesthetic \code{label} needs to be explicitly supplied in the
 #'   call, and labels built on the fly.
@@ -666,12 +675,12 @@ StatFitAugment <-
 #'   as argument by the user, but instead a data frame with the variables mapped
 #'   to aesthetics. In other words, it respects the grammar of graphics and
 #'   consequently within arguments passed through \code{method.args} names of
-#'   aesthetics like $x$ and $y$ should be used intead of the original variable
+#'   aesthetics like $x$ and $y$ should be used instead of the original variable
 #'   names, while data is automatically passed the data frame. This helps ensure
 #'   that the model is fitted to the same data as plotted in other layers.
 #'
 #' @section Warning!: Not all `glance()` methods are defined in package 'broom'.
-#'   `glance()` especializations for mixed models fits of classes `lme`, `nlme`,
+#'   `glance()` specializations for mixed models fits of classes `lme`, `nlme`,
 #'   `lme4`, and many others are defined in package 'broom.mixed'.
 #'
 #' @section Handling of grouping: \code{stat_fit_tidy} applies the function
@@ -681,14 +690,25 @@ StatFitAugment <-
 #'   with results from \code{t.test()} or ANOVA or ANCOVA. In such cases use
 #'   instead \code{stat_fit_tb()} which applies the model fitting per panel.
 #'
-#' @section Computed variables: The output of \code{tidy()} is returned after
-#'   reshaping it into a single row. Grouping is respected, and the model fit
-#'   separatately to each group of data. The returned \code{data} object has one
-#'   row for each group within a panel. To use the intercept, note that output
-#'   of \code{tidy()} is renamed from \code{(Intercept)} to \code{Intercept}.
+#' @return The output of \code{tidy()} is returned after reshaping it into a
+#'   single row. Grouping is respected, and the model fitted separately to each
+#'   group of data. The returned \code{data} object has one row for each group
+#'   within a panel. To use the intercept, note that output of \code{tidy()} is
+#'   renamed from \code{(Intercept)} to \code{Intercept}. Otherwise, the names
+#'   of the columns in the returned data are based on those returned by the
+#'   \code{tidy()} method for the model fit class returned by the fit function.
+#'   These will frequently differ from the name of values returned by the print
+#'   methods corresponding to the fit or test function used. To explore the
+#'   values returned by this statistic including the name of variables/columns,
+#'   which vary depending on the model fitting function and model formula, we
+#'   suggest the use of \code{\link[gginnards]{geom_debug}}. An example is shown
+#'   below. Names of columns as returned by default are not always syntactically
+#'   valid R names making it necessary to use back ticks to access them.
+#'   Syntactically valid names are guaranteed if \code{sanitize.names = TRUE} is
+#'   added to the call.
 #'
-#'   To explore the values returned by this statistic, which vary depending
-#'   on the model fitting function and model formula we suggest the use of
+#'   To explore the values returned by this statistic, which vary depending on
+#'   the model fitting function and model formula we suggest the use of
 #'   \code{\link[gginnards]{geom_debug}}. An example is shown below.
 #'
 #' @note The statistic \code{stat_fit_tidy} can be used only with
@@ -703,7 +723,7 @@ StatFitAugment <-
 #'   documentation for the version of [tidy()] corresponding to the `method`
 #'   used to fit the model.
 #'
-#' @family Statistics calling generic tidier methods.
+#' @family ggplot statistics for model fits
 #'
 #' @seealso \code{\link[broom]{broom}} and \code{broom.mixed} for details on how
 #'   the tidying of the result of model fits is done.
@@ -712,16 +732,33 @@ StatFitAugment <-
 #'
 #' @examples
 #' library(broom)
-#' library(gginnards)
 #' library(quantreg)
 #'
-#' # Regression by panel, exploring computed variables with geom_debug()
-#' ggplot(mtcars, aes(x = disp, y = mpg)) +
-#'   stat_smooth(method = "lm") +
-#'   geom_point(aes(colour = factor(cyl))) +
-#'   stat_fit_tidy(method = "lm",
-#'                 method.args = list(formula = y ~ x),
-#'                 geom = "debug")
+#' # Inspecting the returned data using geom_debug()
+#' if (requireNamespace("gginnards", quietly = TRUE)) {
+#'   library(gginnards)
+#'
+#' # This provides a quick way of finding out the names of the variables that
+#' # are available for mapping to aesthetics. This is specially important for
+#' # this stat as these names depend on the specific tidy() method used, which
+#' # depends on the method used, such as lm(), used to fit the model.
+#'
+#' # Regression by panel, default column names
+#'   ggplot(mtcars, aes(x = disp, y = mpg)) +
+#'     stat_smooth(method = "lm", formula = y ~ x + I(x^2)) +
+#'     geom_point(aes(colour = factor(cyl))) +
+#'     stat_fit_tidy(method = "lm",
+#'                   method.args = list(formula = y ~ x + I(x^2)),
+#'                   geom = "debug")
+#'
+#' # Regression by panel, sanitized column names
+#'   ggplot(mtcars, aes(x = disp, y = mpg)) +
+#'     stat_smooth(method = "lm", formula = y ~ x + I(x^2)) +
+#'     geom_point(aes(colour = factor(cyl))) +
+#'     stat_fit_tidy(method = "lm",
+#'                   method.args = list(formula = y ~ x + I(x^2)),
+#'                   geom = "debug", sanitize.names = TRUE)
+#' }
 #'
 #' # Regression by panel example
 #' ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -731,8 +768,8 @@ StatFitAugment <-
 #'                 label.x = "right",
 #'                 method.args = list(formula = y ~ x),
 #'                 mapping = aes(label = sprintf("Slope = %.3g\np-value = %.3g",
-#'                                               stat(x_estimate),
-#'                                               stat(x_p.value))))
+#'                                               after_stat(x_estimate),
+#'                                               after_stat(x_p.value))))
 #'
 #' # Regression by group example
 #' ggplot(mtcars, aes(x = disp, y = mpg, colour = factor(cyl))) +
@@ -742,8 +779,8 @@ StatFitAugment <-
 #'                 label.x = "right",
 #'                 method.args = list(formula = y ~ x),
 #'                 mapping = aes(label = sprintf("Slope = %.3g, p-value = %.3g",
-#'                                               stat(x_estimate),
-#'                                               stat(x_p.value))))
+#'                                               after_stat(x_estimate),
+#'                                               after_stat(x_p.value))))
 #'
 #' # Weighted regression example
 #' ggplot(mtcars, aes(x = disp, y = mpg, weight = cyl)) +
@@ -753,8 +790,8 @@ StatFitAugment <-
 #'                 label.x = "right",
 #'                 method.args = list(formula = y ~ x, weights = quote(weight)),
 #'                 mapping = aes(label = sprintf("Slope = %.3g\np-value = %.3g",
-#'                                               stat(x_estimate),
-#'                                               stat(x_p.value))))
+#'                                               after_stat(x_estimate),
+#'                                               after_stat(x_p.value))))
 #'
 #' # Correlation test
 #' ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -764,8 +801,8 @@ StatFitAugment <-
 #'                 label.y = "bottom",
 #'                 method.args = list(formula = ~ x + y),
 #'                 mapping = aes(label = sprintf("R = %.3g\np-value = %.3g",
-#'                                               stat(`_estimate`),
-#'                                               stat(`_p.value`))))
+#'                                               after_stat(`_estimate`),
+#'                                               after_stat(`_p.value`))))
 #'
 #' # Quantile regression
 #' ggplot(mtcars, aes(x = disp, y = mpg)) +
@@ -776,8 +813,8 @@ StatFitAugment <-
 #'                 method.args = list(formula = y ~ x),
 #'                 tidy.args = list(se.type = "nid"),
 #'                 mapping = aes(label = sprintf("Slope = %.3g\np-value = %.3g",
-#'                                               stat(x_estimate),
-#'                                               stat(x_p.value))))
+#'                                               after_stat(x_estimate),
+#'                                               after_stat(x_p.value))))
 #'
 stat_fit_tidy <- function(mapping = NULL, data = NULL, geom = "text_npc",
                           method = "lm",
@@ -786,6 +823,7 @@ stat_fit_tidy <- function(mapping = NULL, data = NULL, geom = "text_npc",
                           label.x = "left", label.y = "top",
                           hstep = 0,
                           vstep = NULL,
+                          sanitize.names = FALSE,
                           position = "identity",
                           na.rm = FALSE, show.legend = FALSE,
                           inherit.aes = TRUE, ...) {
@@ -803,6 +841,7 @@ stat_fit_tidy <- function(mapping = NULL, data = NULL, geom = "text_npc",
                                         0.125,
                                         0.075),
                                  vstep),
+                  sanitize.names = sanitize.names,
                   npc.used = grepl("_npc", geom),
                   na.rm = na.rm,
                   ...)
@@ -825,6 +864,7 @@ fit_tidy_compute_group_fun <- function(data,
                                        label.y,
                                        hstep,
                                        vstep,
+                                       sanitize.names,
                                        npc.used) {
   force(data)
   if (length(unique(data$x)) < 2) {
@@ -946,6 +986,10 @@ fit_tidy_compute_group_fun <- function(data,
     z$npcy <- NA_real_
   }
 
+  if (sanitize.names) {
+    names(z) <- make.names(names(z), unique = TRUE)
+  }
+
   z
 }
 
@@ -957,8 +1001,8 @@ StatFitTidy <-
   ggplot2::ggproto("StatFitTidy", ggplot2::Stat,
                    compute_group = fit_tidy_compute_group_fun,
                    default_aes =
-                     ggplot2::aes(npcx = stat(npcx),
-                                  npcy = stat(npcy),
+                     ggplot2::aes(npcx = after_stat(npcx),
+                                  npcy = after_stat(npcy),
                                   hjust = "inward",
                                   vjust = "inward"),
                    required_aes = c("x", "y")
