@@ -29,6 +29,8 @@
 #' @param method.args named list with additional arguments.
 #' @param formula a "formula" object. Using aesthetic names instead of
 #'   original variable names.
+#' @param orientation character Either "x" or "y" controlling the default for
+#'   \code{formula}.
 #'
 #' @details This stat can be used to automatically highlight residuals as
 #'   segments in a plot of a fitted model equation. This stat only
@@ -45,8 +47,10 @@
 #'   ensure that the model is fitted to the same data as plotted in other
 #'   layers.
 #'
-#' @note In the case of \code{method = "rq"} quantiles is fixed at \code{tau = 0.5}
-#'   unless \code{method.args} has length > 0.
+#' @note In the case of \code{method = "rq"} quantiles are fixed at \code{tau =
+#'   0.5} unless \code{method.args} has length > 0. Parameter \code{orientation}
+#'   is redundant as it only affects the default for \code{formula} but is
+#'   included for consistency with \code{ggplot2}.
 #'
 #' @section Computed variables: Data frame with same \code{nrow} as \code{data}
 #'   as subset for each group containing five numeric variables. \describe{
@@ -59,17 +63,42 @@
 #'   can also see in addition to the computed values the default mapping of the
 #'   fitted values to aesthetics \code{xend} and \code{yend}.
 #'
-#' @family statistics for linear model fits
+#' @family ggplot statistics for model fits
 #'
 #' @examples
-#' library(gginnards) # needed for geom_debug()
+#' # generate artificial data
 #' library(MASS)
 #'
-#' # generate artificial data
 #' set.seed(4321)
 #' x <- 1:100
 #' y <- (x + x^2 + x^3) + rnorm(length(x), mean = 0, sd = mean(x^3) / 4)
-#' my.data <- data.frame(x, y, group = c("A", "B"), y2 = y * c(0.5,2))
+#' my.data <- data.frame(x, y)
+#'
+#' # plot residuals from linear model
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_smooth(method = "lm", formula = y ~ x) +
+#'   stat_fit_deviations(method = "lm", formula = y ~ x, colour = "red") +
+#'   geom_point()
+#'
+#' # plot residuals from linear model with y as explanatory variable
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_smooth(method = "lm", formula = y ~ x, orientation = "y") +
+#'   stat_fit_deviations(method = "lm", formula = x ~ y, colour = "red") +
+#'   geom_point()
+#'
+#' # as above using orientation
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_smooth(method = "lm", orientation = "y") +
+#'   stat_fit_deviations(orientation = "y", colour = "red") +
+#'   geom_point()
+#'
+#' # both regressions and their deviations
+#' ggplot(my.data, aes(x, y)) +
+#'   geom_smooth(method = "lm") +
+#'   stat_fit_deviations(colour = "blue") +
+#'   geom_smooth(method = "lm", orientation = "y", colour = "red") +
+#'   stat_fit_deviations(orientation = "y", colour = "red") +
+#'   geom_point()
 #'
 #' # give a name to a formula
 #' my.formula <- y ~ poly(x, 3, raw = TRUE)
@@ -91,9 +120,16 @@
 #'   stat_fit_deviations(formula = my.formula, method = "rlm", colour = "red") +
 #'   geom_point()
 #'
-#' # plot resistant regression
-#' ggplot(my.data, aes(x, y)) +
-#'   stat_fit_deviations(formula = my.formula, method = "lqs", colour = "red") +
+#' # plot robust regression with weights indicated by colour
+#' my.data.outlier <- my.data
+#' my.data.outlier[6, "y"] <- my.data.outlier[6, "y"] * 10
+#' ggplot(my.data.outlier, aes(x, y)) +
+#'   stat_smooth(method = MASS::rlm, formula = my.formula) +
+#'   stat_fit_deviations(formula = my.formula, method = "rlm",
+#'                       mapping = aes(colour = after_stat(weights)),
+#'                       show.legend = TRUE) +
+#'   scale_color_gradient(low = "red", high = "blue", limits = c(0, 1),
+#'                        guide = "colourbar") +
 #'   geom_point()
 #'
 #' # plot quantile regression (= median regression)
@@ -109,12 +145,21 @@
 #'                       method = "rq", method.args = list(tau = 0.75)) +
 #'   geom_point()
 #'
+#' # inspecting the returned data
+#' if (requireNamespace("gginnards", quietly = TRUE)) {
+#'   library(gginnards)
+#'
 #' # plot, using geom_debug() to explore the after_stat data
-#' ggplot(my.data, aes(x, y)) +
-#'   geom_smooth(method = "lm", formula = my.formula) +
-#'   stat_fit_deviations(formula = my.formula, colour = "red",
-#'   geom = "debug") +
-#'   geom_point()
+#'   ggplot(my.data, aes(x, y)) +
+#'     geom_smooth(method = "lm", formula = my.formula) +
+#'     stat_fit_deviations(formula = my.formula, geom = "debug") +
+#'     geom_point()
+#'
+#'   ggplot(my.data.outlier, aes(x, y)) +
+#'     stat_smooth(method = MASS::rlm, formula = my.formula) +
+#'     stat_fit_deviations(formula = my.formula, method = "rlm", geom = "debug") +
+#'     geom_point()
+#' }
 #'
 #' @export
 #'
@@ -123,7 +168,9 @@ stat_fit_deviations <- function(mapping = NULL, data = NULL, geom = "segment",
                                method.args = list(),
                                formula = NULL,
                                position = "identity",
-                               na.rm = FALSE, show.legend = FALSE,
+                               na.rm = FALSE,
+                               orientation = NA,
+                               show.legend = FALSE,
                                inherit.aes = TRUE, ...) {
   ggplot2::layer(
     stat = StatFitDeviations, data = data, mapping = mapping, geom = geom,
@@ -132,50 +179,97 @@ stat_fit_deviations <- function(mapping = NULL, data = NULL, geom = "segment",
                   method.args = method.args,
                   formula = formula,
                   na.rm = na.rm,
+                  orientation = orientation,
                   ...)
   )
 }
 
+# Define here to avoid a note in check as the imports are not seen by checks
+# when the function is defined in-line in the ggproto object.
+#' @rdname ggpmisc-ggproto
+#'
+#' @format NULL
+#' @usage NULL
+#'
+deviations_compute_group_fun <- function(data,
+                                         scales,
+                                         method,
+                                         method.args,
+                                         formula,
+                                         orientation) {
+  stopifnot(!any(c("formula", "data") %in% names(method.args)))
+  if (is.null(data$weight)) {
+    data$weight <- 1
+  }
+
+  # we guess formula from orientation
+  if (is.null(formula)) {
+    if (is.na(orientation) || orientation == "x") {
+      formula = y ~ x
+    } else if (orientation == "y") {
+      formula = x ~ y
+    }
+  }
+  # we guess orientation from formula
+  if (is.na(orientation)) {
+    orientation <- unname(c(x = "y", y = "x")[as.character(formula)[2]])
+  }
+
+  if (is.function(method)) {
+    fun <- method
+  } else if (is.character(method)) {
+    if (method == "rq" && length(method.args) == 0) {
+      method.args <- list(tau = 0.5)
+    }
+    fun <- switch(method,
+                  lm = stats::lm,
+                  rlm = MASS::rlm,
+                  lqs = MASS::lqs,
+                  rq = quantreg::rq,
+                  stop("Method '", method, "' not yet implemented.")
+    )
+  } else {
+    stop("Method '", method, "' not yet implemented.")
+  }
+  mf <- do.call(fun,
+                args = c(list(formula = formula, data = data,
+                              weights = quote(weight)),
+                         method.args))
+  fitted.vals <- stats::fitted(mf)
+  if (exists("w", mf)) {
+    weight.vals <- mf[["w"]]
+  } else {
+    weight.vals <- stats::weights(mf)
+    weight.vals <- ifelse(length(weight.vals) == length(fitted.vals),
+                          weight.vals,
+                          rep_len(NA_real_, length(fitted.vals)))
+  }
+  if (orientation == "y") {
+    data.frame(x = data$x,
+               y = data$y,
+               x.fitted = fitted.vals,
+               y.fitted = data$y,
+               weights = weight.vals,
+               hjust = 0)
+  } else {
+    data.frame(x = data$x,
+               y = data$y,
+               x.fitted = data$x,
+               y.fitted = fitted.vals,
+               weights = weight.vals,
+               hjust = 0)
+  }
+}
+
 #' @rdname ggpmisc-ggproto
 #' @format NULL
 #' @usage NULL
 #' @export
 StatFitDeviations <-
   ggplot2::ggproto("StatFitDeviations", ggplot2::Stat,
-                   compute_group = function(data,
-                                            scales,
-                                            method,
-                                            method.args,
-                                            formula) {
-                     stopifnot(!any(c("formula", "data") %in% names(method.args)))
-                     if (is.function(method)) {
-                       fun <- method
-                     } else if (is.character(method)) {
-                       if (method == "rq" && length(method.args) == 0) {
-                         method.args <- list(tau = 0.5)
-                       }
-                       fun <- switch(method,
-                                     lm = stats::lm,
-                                     rlm = MASS::rlm,
-                                     lqs = MASS::lqs,
-                                     rq = quantreg::rq,
-                                     stop("Method '", method, "' not yet implemented.")
-                       )
-                     } else {
-                       stop("Method '", method, "' not yet implemented.")
-                     }
-                     mf <- do.call(fun,
-                                   args = c(list(formula = formula, data = data),
-                                            method.args))
-                     fitted.vals <- fitted(mf)
-                     data.frame(x = data$x,
-                                y = data$y,
-                                x.fitted = data$x,
-                                y.fitted = fitted.vals,
-                                hjust = 0)
-                   },
+                   compute_group = deviations_compute_group_fun,
                    default_aes =
-                     ggplot2::aes(xend = stat(x.fitted),
-                                  yend = stat(y.fitted)),
+                     ggplot2::aes(xend = after_stat(x.fitted),
+                                  yend = after_stat(y.fitted)),
                    required_aes = c("x", "y")
   )
